@@ -2,8 +2,7 @@ from typing import Any, Optional
 
 from codenames.game import GameState, GivenGuess, GivenHint
 from pydantic import BaseModel, Extra
-
-from . import ModelIdentifier, Solver
+from the_spymaster_solvers_client.structs.base import ModelIdentifier, Solver
 
 
 class BaseResponse(BaseModel):
@@ -23,6 +22,10 @@ class StartGameResponse(BaseResponse):
     game_state: GameState
 
 
+class GetGameStateResponse(BaseResponse):
+    game_state: GameState
+
+
 class HintResponse(BaseResponse):
     given_hint: GivenHint
     game_state: GameState
@@ -33,17 +36,9 @@ class GuessResponse(BaseResponse):
     game_state: GameState
 
 
-class GetGameStateResponse(BaseResponse):
-    game_state: GameState
-
-
 class NextMoveResponse(BaseResponse):
     used_solver: Solver
     used_model_identifier: ModelIdentifier
     given_hint: Optional[GivenHint] = None
     given_guess: Optional[GivenGuess] = None
     game_state: GameState
-
-
-class LoadModelsResponse(BaseResponse):
-    loaded_models_count: int
